==> A.i386-pc-linux-rh6.1.tar.gz: A.i386-pc-linux-rh6.1/dbgcf.h <==

#define HOST_CPU "i686"
#define HOST_VENDOR "pc"
#define HOST_OS "linux"
#define HOST_OS_NAME "linux"
#define HOST_OS_VERSION "2.2.16-1cucs"
#define HOST_ARCH "i386"
#define HOST_NAME "earth.cs.columbia.edu"
#define USER_NAME "ezk"
#define CONFIG_DATE "Sun Jun 11 02:49:53 EDT 2000"
#define PACKAGE "am-utils"
#define VERSION "6.1a2"
#define PACKAGE "am-utils"
#define VERSION "6.1a2"
#define DEBUG 1
#define HOST_HEADER_VERSION "2.2.14-3cucs"
#define YYTEXT_POINTER 1
#define HAVE_LIBRPCSVC 1
#define HAVE_LIBNSL 1
#define HAVE_LIBGDBM 1
#define HAVE_ALLOCA_H 1
#define HAVE_ALLOCA 1
#define STDC_HEADERS 1
#define HAVE_WAIT3 1
#define HAVE__SETERR_REPLY 1
#define HAVE_BCMP 1
#define HAVE_BCOPY 1
#define HAVE_BZERO 1
#define HAVE_CLNT_CREATE 1
#define HAVE_CLNT_SPCREATEERROR 1
#define HAVE_FLOCK 1
#define HAVE_GET_MYADDRESS 1
#define HAVE_GETCWD 1
#define HAVE_GETDOMAINNAME 1
#define HAVE_GETDTABLESIZE 1
#define HAVE_GETHOSTNAME 1
#define HAVE_GETPAGESIZE 1
#define HAVE_GETTIMEOFDAY 1
#define HAVE_HASMNTOPT 1
#define HAVE_MEMCMP 1
#define HAVE_MEMCPY 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMSET 1
#define HAVE_MKDIR 1
#define HAVE_MKSTEMP 1
#define HAVE_MOUNT 1
#define HAVE_REGCOMP 1
#define HAVE_REGEXEC 1
#define HAVE_RMDIR 1
#define HAVE_SELECT 1
#define HAVE_SETEUID 1
#define HAVE_SETITIMER 1
#define HAVE_SETRESUID 1
#define HAVE_SETSID 1
#define HAVE_SIGACTION 1
#define HAVE_SIGNAL 1
#define HAVE_SOCKET 1
#define HAVE_STRCHR 1
#define HAVE_STRCSPN 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRERROR 1
#define HAVE_STRSPN 1
#define HAVE_STRSTR 1
#define HAVE_SVC_GETREQ 1
#define HAVE_SVC_GETREQSET 1
#define HAVE_SYSLOG 1
#define HAVE_UNAME 1
#define HAVE_UMOUNT 1
#define HAVE_VFORK 1
#define HAVE_VSNPRINTF 1
#define HAVE_WAIT3 1
#define HAVE_WAITPID 1
#define HAVE_CLNT_SPERRNO 1
#define HAVE_HASMNTOPT 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRSTR 1
#define HAVE_UALARM 1
#define HAVE_XDR_ATTRSTAT 1
#define HAVE_XDR_CREATEARGS 1
#define HAVE_XDR_DIRLIST 1
#define HAVE_XDR_DIROPARGS 1
#define HAVE_XDR_DIROPOKRES 1
#define HAVE_XDR_DIROPRES 1
#define HAVE_XDR_DIRPATH 1
#define HAVE_XDR_ENTRY 1
#define HAVE_XDR_EXPORTNODE 1
#define HAVE_XDR_EXPORTS 1
#define HAVE_XDR_FATTR 1
#define HAVE_XDR_FHANDLE 1
#define HAVE_XDR_FHSTATUS 1
#define HAVE_XDR_FILENAME 1
#define HAVE_XDR_FTYPE 1
#define HAVE_XDR_GROUPNODE 1
#define HAVE_XDR_GROUPS 1
#define HAVE_XDR_LINKARGS 1
#define HAVE_XDR_MOUNTBODY 1
#define HAVE_XDR_MOUNTLIST 1
#define HAVE_XDR_NAME 1
#define HAVE_XDR_NFS_FH 1
#define HAVE_XDR_NFSCOOKIE 1
#define HAVE_XDR_NFSPATH 1
#define HAVE_XDR_NFSSTAT 1
#define HAVE_XDR_NFSTIME 1
#define HAVE_XDR_POINTER 1
#define HAVE_XDR_READARGS 1
#define HAVE_XDR_READDIRARGS 1
#define HAVE_XDR_READDIRRES 1
#define HAVE_XDR_READLINKRES 1
#define HAVE_XDR_READOKRES 1
#define HAVE_XDR_READRES 1
#define HAVE_XDR_RENAMEARGS 1
#define HAVE_XDR_SATTR 1
#define HAVE_XDR_SATTRARGS 1
#define HAVE_XDR_STATFSOKRES 1
#define HAVE_XDR_STATFSRES 1
#define HAVE_XDR_SYMLINKARGS 1
#define HAVE_XDR_WRITEARGS 1
#define HAVE_DIRENT_H 1
#define STDC_HEADERS 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_ARPA_NAMESER_H 1
#define HAVE_ARPA_INET_H 1
#define HAVE_DB1_NDBM_H 1
#define HAVE_LINUX_AUTO_FS_H 1
#define HAVE_LINUX_FS_H 1
#define HAVE_LINUX_KDEV_T_H 1
#define HAVE_LINUX_LIST_H 1
#define HAVE_LINUX_NFS_H 1
#define HAVE_LINUX_NFS_MOUNT_H 1
#define HAVE_LINUX_POSIX_TYPES_H 1
#define HAVE_NET_IF_H 1
#define HAVE_NET_ROUTE_H 1
#define HAVE_NETINET_IF_ETHER_H 1
#define HAVE_NETINET_IN_H 1
#define HAVE_NFS_NFS_H 1
#define HAVE_RPC_AUTH_DES_H 1
#define HAVE_RPC_PMAP_CLNT_H 1
#define HAVE_RPC_PMAP_PROT_H 1
#define HAVE_RPC_RPC_H 1
#define HAVE_RPC_TYPES_H 1
#define HAVE_RPC_XDR_H 1
#define HAVE_RPCSVC_MOUNT_H 1
#define HAVE_RPCSVC_NFS_PROT_H 1
#define HAVE_RPCSVC_NIS_H 1
#define HAVE_RPCSVC_YP_PROT_H 1
#define HAVE_RPCSVC_YPCLNT_H 1
#define HAVE_SYS_DIR_H 1
#define HAVE_SYS_ERRNO_H 1
#define HAVE_SYS_FILE_H 1
#define HAVE_SYS_IOCTL_H 1
#define HAVE_SYS_MOUNT_H 1
#define HAVE_SYS_PARAM_H 1
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_SYS_SIGNAL_H 1
#define HAVE_SYS_SOCKET_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_STATFS_H 1
#define HAVE_SYS_SYSCALL_H 1
#define HAVE_SYS_SYSLOG_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_UIO_H 1
#define HAVE_SYS_UTSNAME_H 1
#define HAVE_SYS_VFS_H 1
#define HAVE_ASSERT_H 1
#define HAVE_CTYPE_H 1
#define HAVE_ERRNO_H 1
#define HAVE_FCNTL_H 1
#define HAVE_GRP_H 1
#define HAVE_LIBGEN_H 1
#define HAVE_MALLOC_H 1
#define HAVE_MEMORY_H 1
#define HAVE_MNTENT_H 1
#define HAVE_NDBM_H 1
#define HAVE_NETDB_H 1
#define HAVE_PWD_H 1
#define HAVE_REGEX_H 1
#define HAVE_RESOLV_H 1
#define HAVE_SETJMP_H 1
#define HAVE_SIGNAL_H 1
#define HAVE_STDARG_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STDIO_H 1
#define HAVE_STRING_H 1
#define HAVE_STRINGS_H 1
#define HAVE_SYSLOG_H 1
#define HAVE_TIME_H 1
#define HAVE_VARARGS_H 1
#define HAVE_UNISTD_H 1
#define TIME_WITH_SYS_TIME 1
#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_linux.h"
#define HAVE_STRUCT_MNTENT 1
#define HAVE_STRUCT_NFS_ARGS 1
#define nfs_args_t struct nfs_args
#define NFS_FH_FIELD root
#define am_nfs_fh nfs_fh
#define GETGROUPS_T gid_t
#define RETSIGTYPE void
#define HAVE_FHANDLE 1
#define MTYPE_TYPE char *
#define MTYPE_PRINTF_TYPE "%s"
#define YP_ORDER_OUTORDER_TYPE int
#define RECVFROM_FROMLEN_TYPE int
#define AUTH_CREATE_GIDLIST_TYPE gid_t
#define SVC_IN_ARG_TYPE caddr_t
#define XDRPROC_T_TYPE xdrproc_t
#define voidp void *
#define HAVE_EXTERN_SYS_ERRLIST 1
#define HAVE_EXTERN_OPTARG 1
#define HAVE_EXTERN_CLNT_SPCREATEERROR 1
#define HAVE_EXTERN_CLNT_SPERRNO 1
#define HAVE_EXTERN_FREE 1
#define HAVE_EXTERN_GET_MYADDRESS 1
#define HAVE_EXTERN_GETDOMAINNAME 1
#define HAVE_EXTERN_GETDTABLESIZE 1
#define HAVE_EXTERN_GETHOSTNAME 1
#define HAVE_EXTERN_GETLOGIN 1
#define HAVE_EXTERN_GETPAGESIZE 1
#define HAVE_EXTERN_GETWD 1
#define HAVE_EXTERN_INNETGR 1
#define HAVE_EXTERN_MKSTEMP 1
#define HAVE_EXTERN_SBRK 1
#define HAVE_EXTERN_SETEUID 1
#define HAVE_EXTERN_SETITIMER 1
#define HAVE_EXTERN_STRCASECMP 1
#define HAVE_EXTERN_STRDUP 1
#define HAVE_EXTERN_STRSTR 1
#define HAVE_EXTERN_UALARM 1
#define HAVE_EXTERN_USLEEP 1
#define HAVE_EXTERN_WAIT3 1
#define HAVE_EXTERN_VSNPRINTF 1
#define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
#define HAVE_LONG_FILE_NAMES 1
#define HAVE_RESTARTABLE_SYSCALLS 1
#define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
#define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
#define HAVE_FIELD_NFS_ARGS_T_BSIZE 1
#define HAVE_FIELD_NFS_ARGS_T_FHSIZE 1
#define HAVE_FIELD_NFS_ARGS_T_NAMLEN 1
#define HAVE_FIELD_NFS_ARGS_T_VERSION 1
#define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
#define HAVE_FIELD_UMNTREQUEST_RDEVID 1
#define HAVE_MAP_FILE 1
#define HAVE_MAP_NDBM 1
#define HAVE_MAP_NIS 1
#define HAVE_MAP_NISPLUS 1
#define HAVE_MAP_PASSWD 1
#define HAVE_MAP_UNION 1
#define HAVE_FS_AUTOFS 1
#define HAVE_FS_CDFS 1
#define HAVE_FS_NFS 1
#define HAVE_FS_NFS3 1
#define HAVE_FS_PCFS 1
#define HAVE_FS_UFS 1
#define HAVE_FS_EFS 1
#define HAVE_AMU_FS_AUTO 1
#define HAVE_AMU_FS_DIRECT 1
#define HAVE_AMU_FS_TOPLVL 1
#define HAVE_AMU_FS_ERROR 1
#define HAVE_AMU_FS_INHERIT 1
#define HAVE_AMU_FS_PROGRAM 1
#define HAVE_AMU_FS_LINK 1
#define HAVE_AMU_FS_LINKX 1
#define HAVE_AMU_FS_HOST 1
#define HAVE_AMU_FS_NFSX 1
#define HAVE_AMU_FS_NFSL 1
#define HAVE_AMU_FS_UNION 1
#define MOUNT_TYPE_NFS MNTTYPE_NFS
#define MOUNT_TYPE_NFS3 MNTTYPE_NFS3
#define MOUNT_TYPE_UFS "ext2"
#define MOUNT_TYPE_EFS "efs"
#define MOUNT_TYPE_CDFS MNTTYPE_ISO9660
#define MOUNT_TYPE_PCFS "vfat"
#define MOUNT_TYPE_AUTOFS "autofs"
#define MOUNT_TYPE_IGNORE MNTTYPE_IGNORE
#define MNTTAB_TYPE_NFS "nfs"
#define MNTTAB_TYPE_NFS3 "nfs"
#define MNTTAB_TYPE_UFS "ext2"
#define MNTTAB_TYPE_EFS "efs"
#define MNTTAB_TYPE_CDFS "iso9660"
#define MNTTAB_TYPE_PCFS "vfat"
#define MNTTAB_TYPE_AUTOFS "autofs"
#define MNTTAB_OPT_NOAUTO "noauto"
#define MNTTAB_OPT_NOSUID "nosuid"
#define MNTTAB_OPT_RO "ro"
#define MNTTAB_OPT_RW "rw"
#define MNTTAB_OPT_SUID "suid"
#define MNT2_GEN_OPT_NODEV 0x4
#define MNT2_GEN_OPT_NOEXEC 0x8
#define MNT2_GEN_OPT_NOSUID 0x2
#define MNT2_GEN_OPT_RDONLY 0x1
#define MNT2_GEN_OPT_SYNCHRONOUS 0x10
#define MNT2_NFS_OPT_INTR 0x2
#define MNT2_NFS_OPT_NOAC 0x20
#define MNT2_NFS_OPT_NOCTO 0x10
#define MNT2_NFS_OPT_POSIX 0x8
#define MNT2_NFS_OPT_SOFT 0x1
#define MNT2_NFS_OPT_TCP 0x40
#define MNT2_NFS_OPT_VER3 0x80
#define HIDE_MOUNT_TYPE "nfs"
#define MOUNT_TABLE_ON_FILE 1
#define MNTTAB_FILE_NAME "/etc/mtab"

==> A.i386-pc-linux-rh6.2.tar.gz: A.i386-pc-linux-rh6.2/dbgcf.h <==

#define HOST_CPU "i686"
#define HOST_VENDOR "pc"
#define HOST_OS "linux"
#define HOST_OS_NAME "linux"
#define HOST_OS_VERSION "2.2.19-2cucs"
#define HOST_ARCH "i386"
#define HOST_NAME "earth.cs.columbia.edu"
#define USER_NAME "ezk"
#define CONFIG_DATE "Tue Jul  3 20:36:13 EDT 2001"
#define PACKAGE "am-utils"
#define VERSION "6.0.8s1"
#define PACKAGE "am-utils"
#define VERSION "6.0.8s1"
#define DEBUG 1
#define HOST_HEADER_VERSION "2.2.19-2cucs"
#define YYTEXT_POINTER 1
#define HAVE_LIBRPCSVC 1
#define HAVE_LIBNSL 1
#define HAVE_LIBLDAP 1
#define HAVE_LIBGDBM 1
#define HAVE_ALLOCA_H 1
#define HAVE_ALLOCA 1
#define STDC_HEADERS 1
#define HAVE_WAIT3 1
#define HAVE__SETERR_REPLY 1
#define HAVE_BCMP 1
#define HAVE_BCOPY 1
#define HAVE_BZERO 1
#define HAVE_CLNT_CREATE 1
#define HAVE_CLNT_SPCREATEERROR 1
#define HAVE_FLOCK 1
#define HAVE_GET_MYADDRESS 1
#define HAVE_GETCWD 1
#define HAVE_GETDOMAINNAME 1
#define HAVE_GETDTABLESIZE 1
#define HAVE_GETHOSTNAME 1
#define HAVE_GETPAGESIZE 1
#define HAVE_GETTIMEOFDAY 1
#define HAVE_HASMNTOPT 1
#define HAVE_LDAP_OPEN 1
#define HAVE_MEMCMP 1
#define HAVE_MEMCPY 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMSET 1
#define HAVE_MKDIR 1
#define HAVE_MKSTEMP 1
#define HAVE_MOUNT 1
#define HAVE_REGCOMP 1
#define HAVE_REGEXEC 1
#define HAVE_RMDIR 1
#define HAVE_SELECT 1
#define HAVE_SETEUID 1
#define HAVE_SETITIMER 1
#define HAVE_SETRESUID 1
#define HAVE_SETSID 1
#define HAVE_SIGACTION 1
#define HAVE_SIGNAL 1
#define HAVE_SOCKET 1
#define HAVE_STRCHR 1
#define HAVE_STRCSPN 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRERROR 1
#define HAVE_STRSPN 1
#define HAVE_STRSTR 1
#define HAVE_SVC_GETREQ 1
#define HAVE_SVC_GETREQSET 1
#define HAVE_SYSLOG 1
#define HAVE_UNAME 1
#define HAVE_UMOUNT 1
#define HAVE_VFORK 1
#define HAVE_VSNPRINTF 1
#define HAVE_WAIT3 1
#define HAVE_WAITPID 1
#define HAVE_CLNT_SPERRNO 1
#define HAVE_HASMNTOPT 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRSTR 1
#define HAVE_UALARM 1
#define HAVE_XDR_ATTRSTAT 1
#define HAVE_XDR_CREATEARGS 1
#define HAVE_XDR_DIRLIST 1
#define HAVE_XDR_DIROPARGS 1
#define HAVE_XDR_DIROPOKRES 1
#define HAVE_XDR_DIROPRES 1
#define HAVE_XDR_DIRPATH 1
#define HAVE_XDR_ENTRY 1
#define HAVE_XDR_EXPORTNODE 1
#define HAVE_XDR_EXPORTS 1
#define HAVE_XDR_FATTR 1
#define HAVE_XDR_FHANDLE 1
#define HAVE_XDR_FHSTATUS 1
#define HAVE_XDR_FILENAME 1
#define HAVE_XDR_FTYPE 1
#define HAVE_XDR_GROUPNODE 1
#define HAVE_XDR_GROUPS 1
#define HAVE_XDR_LINKARGS 1
#define HAVE_XDR_MOUNTBODY 1
#define HAVE_XDR_MOUNTLIST 1
#define HAVE_XDR_NAME 1
#define HAVE_XDR_NFS_FH 1
#define HAVE_XDR_NFSCOOKIE 1
#define HAVE_XDR_NFSPATH 1
#define HAVE_XDR_NFSSTAT 1
#define HAVE_XDR_NFSTIME 1
#define HAVE_XDR_POINTER 1
#define HAVE_XDR_READARGS 1
#define HAVE_XDR_READDIRARGS 1
#define HAVE_XDR_READDIRRES 1
#define HAVE_XDR_READLINKRES 1
#define HAVE_XDR_READOKRES 1
#define HAVE_XDR_READRES 1
#define HAVE_XDR_RENAMEARGS 1
#define HAVE_XDR_SATTR 1
#define HAVE_XDR_SATTRARGS 1
#define HAVE_XDR_STATFSOKRES 1
#define HAVE_XDR_STATFSRES 1
#define HAVE_XDR_SYMLINKARGS 1
#define HAVE_XDR_WRITEARGS 1
#define HAVE_DIRENT_H 1
#define STDC_HEADERS 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_ARPA_NAMESER_H 1
#define HAVE_ARPA_INET_H 1
#define HAVE_DB1_NDBM_H 1
#define HAVE_LINUX_AUTO_FS_H 1
#define HAVE_LINUX_FS_H 1
#define HAVE_LINUX_KDEV_T_H 1
#define HAVE_LINUX_LIST_H 1
#define HAVE_LINUX_NFS_H 1
#define HAVE_LINUX_NFS_MOUNT_H 1
#define HAVE_LINUX_POSIX_TYPES_H 1
#define HAVE_NET_IF_H 1
#define HAVE_NET_ROUTE_H 1
#define HAVE_NETINET_IF_ETHER_H 1
#define HAVE_NETINET_IN_H 1
#define HAVE_NFS_NFS_H 1
#define HAVE_RPC_AUTH_DES_H 1
#define HAVE_RPC_PMAP_CLNT_H 1
#define HAVE_RPC_PMAP_PROT_H 1
#define HAVE_RPC_RPC_H 1
#define HAVE_RPC_TYPES_H 1
#define HAVE_RPC_XDR_H 1
#define HAVE_RPCSVC_MOUNT_H 1
#define HAVE_RPCSVC_NFS_PROT_H 1
#define HAVE_RPCSVC_NIS_H 1
#define HAVE_RPCSVC_YP_PROT_H 1
#define HAVE_RPCSVC_YPCLNT_H 1
#define HAVE_SYS_DIR_H 1
#define HAVE_SYS_ERRNO_H 1
#define HAVE_SYS_FILE_H 1
#define HAVE_SYS_IOCTL_H 1
#define HAVE_SYS_MOUNT_H 1
#define HAVE_SYS_PARAM_H 1
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_SYS_SIGNAL_H 1
#define HAVE_SYS_SOCKET_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_STATFS_H 1
#define HAVE_SYS_SYSCALL_H 1
#define HAVE_SYS_SYSLOG_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_UIO_H 1
#define HAVE_SYS_UTSNAME_H 1
#define HAVE_SYS_VFS_H 1
#define HAVE_ASSERT_H 1
#define HAVE_CTYPE_H 1
#define HAVE_ERRNO_H 1
#define HAVE_FCNTL_H 1
#define HAVE_GRP_H 1
#define HAVE_LBER_H 1
#define HAVE_LDAP_H 1
#define HAVE_LIBGEN_H 1
#define HAVE_MALLOC_H 1
#define HAVE_MEMORY_H 1
#define HAVE_MNTENT_H 1
#define HAVE_NDBM_H 1
#define HAVE_NETDB_H 1
#define HAVE_PWD_H 1
#define HAVE_REGEX_H 1
#define HAVE_RESOLV_H 1
#define HAVE_SETJMP_H 1
#define HAVE_SIGNAL_H 1
#define HAVE_STDARG_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STDIO_H 1
#define HAVE_STRING_H 1
#define HAVE_STRINGS_H 1
#define HAVE_SYSLOG_H 1
#define HAVE_TIME_H 1
#define HAVE_VARARGS_H 1
#define HAVE_UNISTD_H 1
#define TIME_WITH_SYS_TIME 1
#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_linux.h"
#define HAVE_STRUCT_MNTENT 1
#define HAVE_STRUCT_NFS_ARGS 1
#define nfs_args_t struct nfs_args
#define NFS_FH_FIELD root
#define am_nfs_fh nfs_fh
#define GETGROUPS_T gid_t
#define RETSIGTYPE void
#define HAVE_FHANDLE 1
#define MTYPE_TYPE char *
#define MTYPE_PRINTF_TYPE "%s"
#define YP_ORDER_OUTORDER_TYPE int
#define RECVFROM_FROMLEN_TYPE int
#define AUTH_CREATE_GIDLIST_TYPE gid_t
#define SVC_IN_ARG_TYPE caddr_t
#define XDRPROC_T_TYPE xdrproc_t
#define voidp void *
#define HAVE_EXTERN_SYS_ERRLIST 1
#define HAVE_EXTERN_OPTARG 1
#define HAVE_EXTERN_CLNT_SPCREATEERROR 1
#define HAVE_EXTERN_CLNT_SPERRNO 1
#define HAVE_EXTERN_FREE 1
#define HAVE_EXTERN_GET_MYADDRESS 1
#define HAVE_EXTERN_GETDOMAINNAME 1
#define HAVE_EXTERN_GETDTABLESIZE 1
#define HAVE_EXTERN_GETHOSTNAME 1
#define HAVE_EXTERN_GETLOGIN 1
#define HAVE_EXTERN_GETPAGESIZE 1
#define HAVE_EXTERN_GETWD 1
#define HAVE_EXTERN_INNETGR 1
#define HAVE_EXTERN_MKSTEMP 1
#define HAVE_EXTERN_SBRK 1
#define HAVE_EXTERN_SETEUID 1
#define HAVE_EXTERN_SETITIMER 1
#define HAVE_EXTERN_STRCASECMP 1
#define HAVE_EXTERN_STRDUP 1
#define HAVE_EXTERN_STRSTR 1
#define HAVE_EXTERN_UALARM 1
#define HAVE_EXTERN_USLEEP 1
#define HAVE_EXTERN_WAIT3 1
#define HAVE_EXTERN_VSNPRINTF 1
#define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
#define HAVE_LONG_FILE_NAMES 1
#define HAVE_RESTARTABLE_SYSCALLS 1
#define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
#define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
#define HAVE_FIELD_NFS_ARGS_T_BSIZE 1
#define HAVE_FIELD_NFS_ARGS_T_FHSIZE 1
#define HAVE_FIELD_NFS_ARGS_T_NAMLEN 1
#define HAVE_FIELD_NFS_ARGS_T_VERSION 1
#define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
#define HAVE_FIELD_UMNTREQUEST_RDEVID 1
#define HAVE_MAP_FILE 1
#define HAVE_MAP_LDAP 1
#define HAVE_MAP_NDBM 1
#define HAVE_MAP_NIS 1
#define HAVE_MAP_NISPLUS 1
#define HAVE_MAP_PASSWD 1
#define HAVE_MAP_UNION 1
#define HAVE_FS_AUTOFS 1
#define HAVE_FS_CDFS 1
#define HAVE_FS_NFS 1
#define HAVE_FS_NFS3 1
#define HAVE_FS_PCFS 1
#define HAVE_FS_UFS 1
#define HAVE_FS_EFS 1
#define HAVE_AMU_FS_AUTO 1
#define HAVE_AMU_FS_DIRECT 1
#define HAVE_AMU_FS_TOPLVL 1
#define HAVE_AMU_FS_ERROR 1
#define HAVE_AMU_FS_INHERIT 1
#define HAVE_AMU_FS_PROGRAM 1
#define HAVE_AMU_FS_LINK 1
#define HAVE_AMU_FS_LINKX 1
#define HAVE_AMU_FS_HOST 1
#define HAVE_AMU_FS_NFSX 1
#define HAVE_AMU_FS_NFSL 1
#define HAVE_AMU_FS_UNION 1
#define MOUNT_TYPE_NFS MNTTYPE_NFS
#define MOUNT_TYPE_NFS3 MNTTYPE_NFS3
#define MOUNT_TYPE_UFS "ext2"
#define MOUNT_TYPE_EFS "efs"
#define MOUNT_TYPE_CDFS MNTTYPE_ISO9660
#define MOUNT_TYPE_PCFS "vfat"
#define MOUNT_TYPE_AUTOFS "autofs"
#define MOUNT_TYPE_IGNORE MNTTYPE_IGNORE
#define MNTTAB_TYPE_NFS "nfs"
#define MNTTAB_TYPE_NFS3 "nfs"
#define MNTTAB_TYPE_UFS "ext2"
#define MNTTAB_TYPE_EFS "efs"
#define MNTTAB_TYPE_CDFS "iso9660"
#define MNTTAB_TYPE_PCFS "vfat"
#define MNTTAB_TYPE_AUTOFS "autofs"
#define MNTTAB_OPT_NOAUTO "noauto"
#define MNTTAB_OPT_NOSUID "nosuid"
#define MNTTAB_OPT_RO "ro"
#define MNTTAB_OPT_RW "rw"
#define MNTTAB_OPT_SUID "suid"
#define MNT2_GEN_OPT_NODEV 0x4
#define MNT2_GEN_OPT_NOEXEC 0x8
#define MNT2_GEN_OPT_NOSUID 0x2
#define MNT2_GEN_OPT_RDONLY 0x1
#define MNT2_GEN_OPT_SYNCHRONOUS 0x10
#define MNT2_NFS_OPT_INTR 0x2
#define MNT2_NFS_OPT_NOAC 0x20
#define MNT2_NFS_OPT_NOCTO 0x10
#define MNT2_NFS_OPT_NONLM 0x200
#define MNT2_NFS_OPT_POSIX 0x8
#define MNT2_NFS_OPT_SOFT 0x1
#define MNT2_NFS_OPT_TCP 0x40
#define MNT2_NFS_OPT_VER3 0x80
#define HIDE_MOUNT_TYPE "nfs"
#define MOUNT_TABLE_ON_FILE 1
#define MNTTAB_FILE_NAME "/etc/mtab"
